import { WebAuthnClient } from "@gel/auth-core/webauthn";
export function getConfig(options) {
    const baseUrl = options.baseUrl.replace(/\/$/, "");
    const authRoutesPath = options.authRoutesPath?.replace(/^\/|\/$/g, "") ?? "auth";
    return {
        baseUrl,
        authRoutesPath,
        authCookieName: options.authCookieName ?? "gel-session",
        pkceVerifierCookieName: options.pkceVerifierCookieName ?? "gel-pkce-verifier",
        passwordResetPath: options.passwordResetPath,
        magicLinkFailurePath: options.magicLinkFailurePath,
        authRoute: `${baseUrl}/${authRoutesPath}`,
    };
}
export default function createClientAuth(options) {
    return new ClientAuth(options);
}
export class ClientAuth {
    config;
    isSecure;
    webAuthnClient;
    constructor(options) {
        this.config = getConfig(options);
        this.isSecure = this.config.baseUrl.startsWith("https");
        this.webAuthnClient = new WebAuthnClient({
            signupOptionsUrl: `${this.config.authRoute}/webauthn/signup/options`,
            signupUrl: `${this.config.authRoute}/webauthn/signup`,
            signinOptionsUrl: `${this.config.authRoute}/webauthn/signin/options`,
            signinUrl: `${this.config.authRoute}/webauthn/signin`,
            verifyUrl: `${this.config.authRoute}/webauthn/verify`,
        });
    }
    getOAuthUrl(providerName) {
        return `${this.config.authRoute}/oauth?${new URLSearchParams({
            provider_name: providerName,
        }).toString()}`;
    }
    getBuiltinUIUrl() {
        return `${this.config.authRoute}/builtin/signin`;
    }
    getBuiltinUISignUpUrl() {
        return `${this.config.authRoute}/builtin/signup`;
    }
    getSignoutUrl() {
        return `${this.config.authRoute}/signout`;
    }
}
